# Table of Contents

- [mandatory-attributes](<./mandatory-attributes.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Mandatory Attributes](<./Mandatory-Attributes.md>)
  - [Introduction](<./Mandatory-Attributes/Introduction.md>)
  - [Filling Mandatory Attributes](<./Mandatory-Attributes/Filling-Mandatory-Attributes.md>)
  - [Mandatory Attributes and Quality Seal](<./Mandatory-Attributes/Mandatory-Attributes-and-Quality-Seal.md>)
  - [Defining Mandatory Attributes](<./Mandatory-Attributes/Defining-Mandatory-Attributes.md>)
  - [Interoperability of Mandatory and Conditional Attributes](<./Mandatory-Attributes/Interoperability-of-Mandatory-and-Conditional-Attributes.md>)
  - [Was this page helpful?](<./Mandatory-Attributes/Was-this-page-helpful.md>)
